HTTPMethod enum
Values
- get → const HTTPMethod
-
The get method requests a representation of the specified resource. Requests using get should only retrieve data.
const HTTPMethod._('GET') - head → const HTTPMethod
-
The head method asks for a response identical to that of a get request, but without the response body.
const HTTPMethod._('HEAD') - post → const HTTPMethod
-
The post method is used to submit an entity to the specified resource, often causing a change in state or side effects on the server.
const HTTPMethod._('POST') - put → const HTTPMethod
-
The put method replaces all current representations of the target resource with the request payload.
const HTTPMethod._('PUT') - delete → const HTTPMethod
-
The delete method deletes the specified resource.
const HTTPMethod._('DELETE') - patch → const HTTPMethod
-
The patch method is used to apply partial modifications to a resource.
const HTTPMethod._('PATCH')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isAllowedPayloadMethod → bool
-
no setter
- name → String
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
all
→ const List<
HTTPMethod> -
allowedPayloadMethods
→ const List<
HTTPMethod> - Taken from BaseOptions. The default methods that are considered to have a payload. Only for these methods a default content-type header is added, if no specified.
-
values
→ const List<
HTTPMethod> - A constant List of the values in this enum, in order of their declaration.