LogOption enum
Values
- request → const LogOption
-
const LogOption(1 << 0) - requestHeaders → const LogOption
-
const LogOption(1 << 1) - requestParameters → const LogOption
-
const LogOption(1 << 2) - requestBody → const LogOption
-
const LogOption(1 << 3) - rawRequest → const LogOption
-
const LogOption(1 << 4) - urlResponse → const LogOption
-
const LogOption(1 << 5) - responseStatus → const LogOption
-
const LogOption(1 << 6) - responseHeaders → const LogOption
-
const LogOption(1 << 7) - responseData → const LogOption
-
const LogOption(1 << 8) - error → const LogOption
-
const LogOption(1 << 9) - cache → const LogOption
-
const LogOption(1 << 10)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited