PrettyLogPrinter class
Constructors
-
PrettyLogPrinter({int stackTraceBeginIndex = 0, int? methodCount = 0, int? errorMethodCount = 10, int lineLength = 100, bool colors = true, bool printEmojis = true, DateTimeFormatter dateTimeFormat = DateTimeFormat.dateAndTime, Map<Level, bool> excludeBox = const {}, bool noBoxingByDefault = false, List<String> excludePaths = const [], Map<Level, AnsiColor>? levelColors, Map<Level, String>? levelEmojis})
-
Properties
-
colors
→ bool
-
Whether ansi colors are used to color the output.
final
-
dateTimeFormat
→ DateTimeFormatter
-
Controls the format of
LogEvent.time.
final
-
errorMethodCount
→ int?
-
Controls the method count in stack traces
when
LogEvent.error was provided.
final
-
excludeBox
→ Map<Level, bool>
-
Controls the ascii 'boxing' of different
Levels.
final
-
excludePaths
→ List<String>
-
A list of custom paths that are excluded from the stack trace.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
levelColors
→ Map<Level, AnsiColor>?
-
Controls the colors used for the different log levels.
final
-
levelEmojis
→ Map<Level, String>?
-
Controls the emojis used for the different log levels.
final
-
lineLength
→ int
-
Controls the length of the divider lines.
final
-
methodCount
→ int?
-
Controls the method count in stack traces
when no
LogEvent.error was provided.
final
-
noBoxingByDefault
→ bool
-
Whether the implicit
bools in excludeBox are true or false by default.
final
-
printEmojis
→ bool
-
Whether emojis are prefixed to the log line.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
stackTraceBeginIndex
→ int
-
The index at which the stack trace should start.
final